/******************************************************************************
 * FILE:
 *    uc_spc58ne84_types.h
 *
 * UC ARCHITECTURE:
 *    PowerPC
 *
 * UC FAMILY:
 *    SPC58

 * DESCRIPTION:
 *    uC derivative specific types that user can use in code.
 *    A usage of these types helps to catch issues when porting between
 *    different uC derivatives.
 *
 * FILE HISTORY:
 *    V1.0    23.09.2017     RO
 *       > Initial version
 *    V2.0    25.01.2018     RO
 *       > file header update
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

#ifndef UC_SPC58NE84_TYPES_H
#define UC_SPC58NE84_TYPES_H


/* ============================================================================
 *                 uC BSP TYPES
 * ==========================================================================*/

/* ----------------------------------------------------------------------------
 * CORE Identification
 * --------------------------------------------------------------------------*/

typedef enum {
	UC_CORE_MAIN_0 = 0,
	UC_CORE_MAIN_1 = 1,
	UC_CORE_IOP    = 2,
} UC_CORE_ID_e;

/* ----------------------------------------------------------------------------
 * CGM CLOCK module
 * --------------------------------------------------------------------------*/

/* SYSTEM CLOCK selection
 * RM Ch69 Mode Entry - ME_<mode>_MC register fields */
typedef enum {
	UC_ME_MODE_SYSCLK_IRCOSC  = 0,
	UC_ME_MODE_SYSCLK_XTAL    = 1,
	UC_ME_MODE_SYSCLK_PLL0    = 2,
	UC_ME_MODE_SYSCLK_PLL1    = 4,
} UC_ME_MODE_SYSCLK_e;

/* ----------------------------------------------------------------------------
 * SYSTEM CLOCK Output
 * --------------------------------------------------------------------------*/

/* Clock selection corresponds to AC6 bridge */
typedef enum {
	UC_SYSCLK0_SELCTL_IRCOSC    = 0,
	UC_SYSCLK0_SELCTL_XOSC      = 1,
	UC_SYSCLK0_SELCTL_PLL0_PHI  = 2,
	UC_SYSCLK0_SELCTL_PLL1_PHI  = 4,
	UC_SYSCLK0_SELCTL_RTC_CLK   = 6,
} UC_SYSCLK0_SELCTL_e;


/* Clock selection corresponds to AC7 bridge */
typedef enum {
	UC_SYSCLK1_SELCTL_IRCOSC    = 0,
	UC_SYSCLK1_SELCTL_XOSC      = 1,
	UC_SYSCLK1_SELCTL_PLL0_PHI  = 2,
	UC_SYSCLK1_SELCTL_PLL1_PHI  = 4,
} UC_SYSCLK1_SELCTL_e;

/* ----------------------------------------------------------------------------
 * PIT timer
 * --------------------------------------------------------------------------*/

/* PIT CHANNELS interface type */
typedef enum {
	UC_PIT_CHANNEL_0 = 0,
	UC_PIT_CHANNEL_1 = 1,
	UC_PIT_CHANNEL_2 = 2,
	UC_PIT_CHANNEL_3 = 3,
	UC_PIT_CHANNEL_4 = 4,
	UC_PIT_CHANNEL_5 = 5,
	UC_PIT_CHANNEL_6 = 6,
	UC_PIT_CHANNEL_7 = 7,
} UC_PIT_CHANNEL_e;

/* ----------------------------------------------------------------------------
 * SIUL IO Interface
 * --------------------------------------------------------------------------*/

/* SIUL PAD output edge rate control
 * RM Ch17 SIUL2 - MSCR_IO register fields */
typedef enum {
	UC_SIUL_OERC_WEAK = 0,
	UC_SIUL_OERC_MEDIUM = 1,
	UC_SIUL_OERC_STRONG = 2,
	UC_SIUL_OERC_VERY_STRONG = 3,
} UC_SIUL_OERC_e;

/* SIUL PAD type
 * RM Ch17 SIUL2 - MSCR_IO register fields */
typedef enum {
	UC_SIUL_TYPE_OUTPUT_DISABLED = 0,
	UC_SIUL_TYPE_OUTPUT_OPEN_DRAIN = 1,
	UC_SIUL_TYPE_OUTPUT_PUSH_PULL = 2,
	UC_SIUL_TYPE_OUTPUT_OPEN_SOURCE = 3,
	UC_SIUL_TYPE_OUTPUT_MICROSECOND_LVDS = 4,
	UC_SIUL_TYPE_OUTPUT_LFAST_LVDS = 5,
} UC_SIUL_TYPE_e;

/* SIUL PAD Input pull up
 * RM Ch17 SIUL2 - MSCR_IO register fields */
typedef enum {
	UC_SIUL_PULL_DISABLE = 0,
	UC_SIUL_PULL_ENABLE = 1,
} UC_SIUL_PULL_e;

/* ----------------------------------------------------------------------------
 * PFLASH Controller
 * --------------------------------------------------------------------------*/

/* PFLASH: PFCR1 Pipeline control
 * RM Ch36 Flash memory controller - PFCR1 register */
typedef enum {
	UC_PFLASH_APC_PIPELINE_DIS = 0,
	UC_PFLASH_APC_PIPELINE_1C_BEFORE = 1,
	UC_PFLASH_APC_PIPELINE_DIS_1WS = 4,
} UC_PFLASH_APC_e;

/* PFLASH: PFCR1 Prefetch control
 * RM Ch36 Flash memory controller - PFCR1 register */
typedef enum {
	UC_PFLASH_PFLIM_NO_PREFETCH = 0,
	UC_PFLASH_PFLIM_ON_MISS = 1,
	UC_PFLASH_PFLIM_ON_MISS_HIT = 2,
} UC_PFLASH_PFLIM_e;

/* PFLASH: PFCR1 Port way configuration
 * RM Ch36 Flash memory controller - PFCR3 register */
typedef enum {
	UC_PFLASH_WCFG_NO_PARTITIONING = 0,
	UC_PFLASH_WCFG_TWO_GROUPS = 2,
} UC_PFLASH_WCFG_e;

/* PFLASH: PFCR3 Port Arbitration
 * RM Ch36 Flash memory controller - PFCR3 register */
typedef enum {
	UC_PFLASH_ARBM_FIXED_PRIO_P0_P1 = 0,
	UC_PFLASH_ARBM_FIXED_PRIO_P1_P0 = 1,
	UC_PFLASH_ARBM_ROUND_ROBIN = 2,
} UC_PFLASH_ARBM_e;

/* ----------------------------------------------------------------------------
 * PRAM Controller
 * --------------------------------------------------------------------------*/

/* PRAM: Port priority field
 * RM Ch35 Platform RAM controller - PRCR1 register */
typedef enum {
	UC_PRAM_PRI_ROUND_ROBIN = 0,
	UC_PRAM_PRI_P0_P1 = 1,
	UC_PRAM_PRI_P1_P0 = 2,
} UC_PRAM_PRI_e;

/* PRAM: Read buffer field
 * RM Ch35 Platform RAM controller - PRCR1 register */
typedef enum {
	UC_PRAM_RB_ENABLE = 0,
	UC_PRAM_RB_DISABLE = 1,
} UC_PRAM_RB_e;


#endif /* UC_SPC58NE84_TYPES_H */
